We can interpret the second-line in the context of the dual plane. We see that we're after the reverse of the original problem. We want the line \(s^*\) that is closest to the point \(l^*\) traveling vertically down.

## Solving the Dual

To do so, we first form the arrangement of the dual in \(O(n^2)\). We build a trapezoidal-decomposition on top of this in \(O(n^2\log n)\) expected time, \(O(n^2)\) space.

We also do the given convex hull pre-processing step on every face. We note that the runtime of this operation is the summation of performing it on each individual face. This is in turn log-linear in the number of edges of each face. That is, the running time is 
\(O(\sum_\text{face i} e(i)\log e(i) ) \leq O(\log n \sum_\text{face i} e(i)\)\) where the inequality follows from the fact that the maximum number of edges a face can have is less than \(O(n^2)\). From here, we note that the sum now simply sums up the edges for all faces. However, an edge can be included in at most faces, so in total this sum includes every edge in the graph at most twice. There are \(O(n^2)\) edges in the graph. As such the total run-time of this pre-processing step is \(O(n^2 \log n)\).

This allows us to find the face that any point we query resides in in \(O(\log n\)\). We then perform a vertical line-query from \(l^*\) and find the bottom-most intersection point with the convex face. By assumption this can be done in \(O(\log n)\).

This gives us the line closest to our point by vertical distance traveling downwards \(implies\) the point found in our original problem shifting the line vertically upwards \(\square\).

* Preprocessing: \(O(n^2 \log n)\) expected.
* Query: \(O( \log n)\) expected.
* Storage: \(O(n^2)\) expected.